pub struct GltfAsset {
pub models: Vec<(Handle<Mesh>, Handle<PbrMaterial>)>,
pub bbox: MeshBbox,
pub properties: HashMap<String, (Vec3, Vec3)>,
/* private fields */
}Expand description
Representation of a 3D GLTF model asset. This will spawn the model and return the parent entity ID. See the crate documentation for usage examples.
Fields
models: Vec<(Handle<Mesh>, Handle<PbrMaterial>)>The list of parsed glTF models. Each model is represented by a mesh and its associated material.
bbox: MeshBboxThe englobing bounding box of the entire model, computed from the bounding boxes of all meshes.
properties: HashMap<String, (Vec3, Vec3)>Named properties (e.g. spawn points) extracted from meshes whose name starts with %P%.
These meshes are not added to Self::models; only their name, position and scale are kept here.