pub struct GltfAsset {
pub path: String,
pub models: Vec<(Handle<Mesh>, Handle<PbrMaterial>)>,
}Expand description
Representation of a 3D GLTF model asset. This will spawn the model and return the parent entity ID. See the crate documentation for usage examples.
Fields
path: Stringmodels: Vec<(Handle<Mesh>, Handle<PbrMaterial>)>The list of parsed glTF models. Each model is represented by a mesh and its associated material.